@@ -99,7 +99,7 @@ static XF86ImageRec Images[] = {
 
 typedef struct
 {
-    GeodeMemPtr vidmem;
+    ExaOffscreenArea *vidmem;
     RegionRec clip;
     CARD32 filter;
     CARD32 colorKey;
@@ -119,7 +119,7 @@ LXCopyFromSys(GeodeRec * pGeode, unsigned char *src, unsigned int dst,
 {
 
     gp_declare_blt(0);
-    gp_set_bpp(16);
+    gp_set_bpp((srcPitch / w) << 3);
 
     gp_set_raster_operation(0xCC);
     gp_set_strides(dstPitch, srcPitch);
@@ -188,13 +188,16 @@ struct
 /* Copy planar YUV data */
 
 static Bool
-LXAllocMem(GeodeRec *pGeode, GeodePortPrivRec *pPriv, int size)
+LXAllocateVidMem(ScrnInfoPtr pScrni, GeodePortPrivRec *pPriv, int size)
 {
     if (!pPriv->vidmem || pPriv->vidmem->size < size) { 
-	if (pPriv->vidmem) 
-		GeodeFreeOffscreen(pGeode, pPriv->vidmem);
+	if (pPriv->vidmem) {
+		exaOffscreenFree(pScrni->pScreen, pPriv->vidmem);
+		pPriv->vidmem = NULL;
+	}
 
-    	pPriv->vidmem = GeodeAllocOffscreen(pGeode, size, 4);
+	pPriv->vidmem = exaOffscreenAlloc(pScrni->pScreen, size, 4,
+			TRUE, NULL, NULL);
 
     	if (pPriv->vidmem == NULL) {
 		ErrorF("Could not allocate memory for the video\n");
@@ -236,8 +239,10 @@ LXCopyPlanar(ScrnInfoPtr pScrni, int id, unsigned char *buf,
     size = YDstPitch * height;
     size += UVDstPitch * height;
 
-    if (LXAllocMem(pGeode, pPriv, size) == FALSE)
+    if (LXAllocateVidMem(pScrni, pPriv, size) == FALSE) {
+	ErrorF("Error allocating an offscreen Planar region.\n");
 	return FALSE;
+    }
 
     /* The top of the source region we want to copy */
     top = y1 & ~1;
@@ -297,8 +302,10 @@ LXCopyPacked(ScrnInfoPtr pScrni, int id, unsigned char *buf,
 
     lines = ((dstPitch * height) + pGeode->Pitch - 1) / pGeode->Pitch;
 
-    if (LXAllocMem(pGeode, pPriv, lines) == FALSE)
+    if (LXAllocateVidMem(pScrni, pPriv, dstPitch * height) == FALSE) {
+	ErrorF("Error allocating an offscreen Packed region.\n");
 	return FALSE;
+    }
 
     /* The top of the source region we want to copy */
     top = y1;
@@ -327,6 +334,7 @@ LXCopyPacked(ScrnInfoPtr pScrni, int id, unsigned char *buf,
 	GeodeCopyGreyscale(buf + srcOffset, pGeode->FBBase + dstOffset,
 	    srcPitch, dstPitch, height, pixels >> 1);
     } else
+	/* FIXME: should lines be used here instead of height? */
 	LXCopyFromSys(pGeode, buf + srcOffset, dstOffset, dstPitch, srcPitch,
 	    height, pixels);
 
@@ -578,7 +586,6 @@ static void
 LXStopVideo(ScrnInfoPtr pScrni, pointer data, Bool exit)
 {
     GeodePortPrivRec *pPriv = (GeodePortPrivRec *) data;
-    GeodeRec *pGeode = GEODEPTR(pScrni);
 
     if (pPriv->videoStatus == 0)
 	return;
@@ -597,7 +604,7 @@ LXStopVideo(ScrnInfoPtr pScrni, pointer data, Bool exit)
 	}
 
 	if (pPriv->vidmem) {
-	    GeodeFreeOffscreen(pGeode, pPriv->vidmem);
+	    exaOffscreenFree(pScrni->pScreen, pPriv->vidmem);
 	    pPriv->vidmem = NULL;
 	}
 
@@ -659,7 +666,7 @@ LXVidBlockHandler(int i, pointer blockData, pointer pTimeout,
 	    if (pPriv->freeTime < now) {
 
 		if (pPriv->vidmem) {
-		    GeodeFreeOffscreen(pGeode, pPriv->vidmem);
+		    exaOffscreenFree(pScrni->pScreen, pPriv->vidmem);
 		    pPriv->vidmem = NULL;
 		}
 
@@ -677,7 +684,7 @@ LXSetupImageVideo(ScreenPtr pScrn)
     XF86VideoAdaptorPtr adapt;
     GeodePortPrivRec *pPriv;
 
-    adapt = xcalloc(1, sizeof(XF86VideoAdaptorRec) +
+    adapt = calloc(1, sizeof(XF86VideoAdaptorRec) +
 	sizeof(GeodePortPrivRec) + sizeof(DevUnion));
 
     if (adapt == NULL) {
@@ -742,7 +749,7 @@ LXSetupImageVideo(ScreenPtr pScrn)
 
 struct OffscreenPrivRec
 {
-    GeodeMemPtr vidmem;
+    ExaOffscreenArea *vidmem;
     Bool isOn;
 };
 
@@ -800,7 +807,7 @@ LXAllocateSurface(ScrnInfoPtr pScrni, int id, unsigned short w,
 {
     GeodeRec *pGeode = GEODEPTR(pScrni);
     int pitch, lines;
-    GeodeMemPtr vidmem;
+    ExaOffscreenArea *vidmem;
     struct OffscreenPrivRec *pPriv;
 
     if (w > 1024 || h > 1024)
@@ -812,7 +819,10 @@ LXAllocateSurface(ScrnInfoPtr pScrni, int id, unsigned short w,
     pitch = ((w << 1) + 15) & ~15;
     lines = ((pitch * h) + (pGeode->Pitch - 1)) / pGeode->Pitch;
 
-    vidmem = GeodeAllocOffscreen(pGeode, lines, 4);
+    /* FIXME: is lines the right parameter to use here,
+     * or should it be height * pitch? */
+    vidmem = exaOffscreenAlloc(pScrni->pScreen, lines, 4, TRUE,
+		NULL, NULL);
 
     if (vidmem == NULL) {
 	ErrorF("Error while allocating an offscreen region.\n");
@@ -822,11 +832,11 @@ LXAllocateSurface(ScrnInfoPtr pScrni, int id, unsigned short w,
     surface->width = w;
     surface->height = h;
 
-    surface->pitches = xalloc(sizeof(int));
+    surface->pitches = malloc(sizeof(int));
 
-    surface->offsets = xalloc(sizeof(int));
+    surface->offsets = malloc(sizeof(int));
 
-    pPriv = xalloc(sizeof(struct OffscreenPrivRec));
+    pPriv = malloc(sizeof(struct OffscreenPrivRec));
 
     if (pPriv && surface->pitches && surface->offsets) {
 
@@ -844,13 +854,15 @@ LXAllocateSurface(ScrnInfoPtr pScrni, int id, unsigned short w,
     }
 
     if (surface->offsets)
-	xfree(surface->offsets);
+	free(surface->offsets);
 
     if (surface->pitches)
-	xfree(surface->pitches);
+	free(surface->pitches);
 
-    if (vidmem)
-	GeodeFreeOffscreen(pGeode, vidmem);
+    if (vidmem) {
+	exaOffscreenFree(pScrni->pScreen, vidmem);
+	vidmem = NULL;
+    }
 
     return BadAlloc;
 }
@@ -871,19 +883,18 @@ LXFreeSurface(XF86SurfacePtr surface)
     struct OffscreenPrivRec *pPriv = (struct OffscreenPrivRec *)
 	surface->devPrivate.ptr;
     ScrnInfoPtr pScrni = surface->pScrn;
-    GeodeRec *pGeode = GEODEPTR(pScrni);
 
     if (pPriv->isOn)
 	LXStopSurface(surface);
 
     if (pPriv->vidmem) {
-	GeodeFreeOffscreen(pGeode, pPriv->vidmem);
+	exaOffscreenFree(pScrni->pScreen, pPriv->vidmem);
 	pPriv->vidmem = NULL;
     }
 
-    xfree(surface->pitches);
-    xfree(surface->offsets);
-    xfree(surface->devPrivate.ptr);
+    free(surface->pitches);
+    free(surface->offsets);
+    free(surface->devPrivate.ptr);
 
     return Success;
 }
@@ -908,7 +919,7 @@ LXInitOffscreenImages(ScreenPtr pScrn)
     XF86OffscreenImagePtr offscreenImages;
 
     /* need to free this someplace */
-    if (!(offscreenImages = xalloc(sizeof(XF86OffscreenImageRec))))
+    if (!(offscreenImages = malloc(sizeof(XF86OffscreenImageRec))))
 	return;
 
     offscreenImages[0].image = &Images[0];
@@ -957,7 +968,7 @@ LXInitVideo(ScreenPtr pScrn)
 	adaptors = &newAdaptor;
     } else {
 	newAdaptors =
-	    xalloc((num_adaptors + 1) * sizeof(XF86VideoAdaptorPtr *));
+	    malloc((num_adaptors + 1) * sizeof(XF86VideoAdaptorPtr *));
 
 	if (newAdaptors) {
 	    memcpy(newAdaptors, adaptors, num_adaptors *
@@ -973,5 +984,5 @@ LXInitVideo(ScreenPtr pScrn)
 	xf86XVScreenInit(pScrn, adaptors, num_adaptors);
 
     if (newAdaptors)
-	xfree(newAdaptors);
+	free(newAdaptors);
 }
